.. _core_device_configuration:

Configuration
-------------

Configure the General Settings to configure the device plugin.

:Device Auto Enrollment: Devices will be automatically enrolled without the
        intervention of an Administrator.

:Field Enrollment Enabled: Devices will enroll for the Field Service.

:Office Enrollemt Enabled: Devices will enroll for the Office Service.

:Offline Cache Refresh Seconds: This is the period of time a device will have
        its offline cache refreshed.

.. image:: general_settings.png

